# Cloudify CLI

[![Circle CI](https://circleci.com/gh/cloudify-cosmo/cloudify-cli.svg?style=shield)](https://circleci.com/gh/cloudify-cosmo/cloudify-cli)
[![Build Status](https://travis-ci.org/cloudify-cosmo/cloudify-cli.svg?branch=master)](https://travis-ci.org/cloudify-cosmo/cloudify-cli)
[![PyPI](http://img.shields.io/pypi/dm/cloudify.svg)](http://img.shields.io/pypi/dm/cloudify.svg)
[![PypI](http://img.shields.io/pypi/v/cloudify.svg)](http://img.shields.io/pypi/v/cloudify.svg)


Cloudify's Command Line Interface.

## Usage

See [Cloudify CLI](http://docs.getcloudify.org/latest/cli/overview/)
